#include "Arduino.h"
#include "SensorBase.h"

SensorBase::SensorBase(char* location, RF24* radio, int senderID)
{
  Location = location;
  Radio = radio;
  SenderID = senderID;
}

void SensorBase::formatMetric(char* buffer, int bufferSize, char* metricType, char*metricPrefix, char* metricName, float value)
{
  char numberBuffer[32];
  dtostrf(value, 0, 5, numberBuffer);
  snprintf(buffer, bufferSize, "%s,%s.%s,%s", metricType, metricPrefix, metricName, numberBuffer);
}

void SensorBase::sendMetric(char* metricType, char* metricPrefix, char* metricName, float value)
{
  char metricString[MAX_METRIC_STRING_SIZE];
  memset(metricString,0,sizeof(metricString));
  formatMetric(metricString, MAX_METRIC_STRING_SIZE, metricType, metricPrefix, metricName, value);
   
  Serial.print(metricString);
  Serial.println(strlen(metricString));

  FragmentedMessage fragmentedMessage(metricString, SenderID);
  
  bool ok;
  for(int fragmentIndex=0; fragmentIndex < fragmentedMessage.NumFragments; fragmentIndex++)
  {  
    ok = Radio->write( fragmentedMessage.Fragments[fragmentIndex], NRF_PACKET_SIZE);
    Serial.print("Fragment #: ");
    Serial.print(fragmentIndex);
    Serial.print(" Send Status: ");
    Serial.println(ok);
  }

  ok = Radio->write( fragmentedMessage.ChecksumFragment, NRF_PACKET_SIZE);
  Serial.print("Checksum Fragment Send Status: ");
  Serial.println(ok);  
}